vmshepherd package
==================

Subpackages
-----------

.. toctree::

    vmshepherd.drivers
    vmshepherd.healthcheck
    vmshepherd.http
    vmshepherd.iaas
    vmshepherd.presets
    vmshepherd.runtime

Submodules
----------

vmshepherd.app module
---------------------

.. automodule:: vmshepherd.app
    :members:
    :undoc-members:
    :show-inheritance:

vmshepherd.utils module
-----------------------

.. automodule:: vmshepherd.utils
    :members:
    :undoc-members:
    :show-inheritance:

Module contents
---------------

.. automodule:: vmshepherd
    :members:
    :undoc-members:
    :show-inheritance:
